@@ -6,7 +6,7 @@ import time
 import random
 import json
 import requests
-from .gooblerpkg.config import colors
+from gooblerpkg.Config import colors
 
 ###################
 ### Goobler 2022 ##
@@ -29,11 +29,11 @@ from .gooblerpkg.config import colors
 # PURE FUNCS:
 
 def start(tkn):
-  resp = requests.get("https://goobler.ericplayzyt.repl.co/api/get_name_using_auth", {"auth": f"{tkn}"}).json()
+  resp = requests.get("https://goobl2.ericplayzyt.repl.co/api/get_name_using_auth", {"auth": f"{tkn}"}).json()
   print(f"Starting {resp['user_name']}...")
-  resp2 = requests.post("https://goobler.ericplayzyt.repl.co/api/login/bot_account", {"auth": f"{tkn}"}).json()
+  resp2 = requests.post("https://goobl2.ericplayzyt.repl.co/api/login/bot_account", {"auth": f"{tkn}"}).json()
   print(resp['user_name'] + "has logged in.")
 
 def Application(client_id=None, token=None):
   if token == None:
-    print(colors.FAIL + colors.BOLD + colors.UNDERLINE + "[GooblerAPI] You cannot execute 'MakeApplication' without the positional arguments, token. Remember, the token is the admin password to your application.")
\ No newline at end of file
+    print(colors._FAIL + colors._BOLD + colors._UNDERLINE + "[GooblerAPI] You cannot execute 'MakeApplication' without the positional arguments, token. Remember, the token is the admin password to your application.")
\ No newline at end of file
